Authors
-------

Created May 2020 by Matthias Cuntz.

It is distributed under the MIT License, see LICENSE file.

Copyright (c) 2009-2022 Matthias Cuntz

Main Authors
    * `Matthias Cuntz`_, E-mail: mc (at) macu (dot) de

Contributors
    * `Arndt Piayda`_, E-mail: arndt (dot) piayda (at) thuenen (dot) de
    * Tino Rau
    * `Juliane Mai`_, E-mail: juliane (dot) mai (at) uwaterloo (dot) ca
    * `Sebastian Müller`_, E-mail: sebastian (dot) mueller (at) ufz (dot) de

.. _Arndt Piayda: https://github.com/peterchenchenchen
.. _Juliane Mai: https://github.com/julemai
.. _Matthias Cuntz: https://github.com/mcuntz
.. _Sebastian Müller: https://github.com/MuellerSeb
